package com.cn.bjca.chatbots.core.client;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.URLUtil;
import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpUtil;
import cn.hutool.http.Method;
import com.cn.bjca.chatbots.core.properties.ChatbotsProperties;
import com.cn.bjca.chatbots.core.util.SignUtil;
import lombok.SneakyThrows;

/**
 * <pre>外呼client</pre>
 *
 * <p>Description</p>
 * <pre>
 *     __
 *    / /____  ___
 *   / __/ _ \/ _ \
 *   \__/\___/ .__/
 *          / / Coding is an art,
 *         /_/      And I'm its Picasso.
 *
 *   ██████  █    ██ ▓█████▄ ▓█████  ██▀███
 * ▒██    ▒  ██  ▓██▒▒██▀ ██▌▓█   ▀ ▓██ ▒ ██▒
 * ░ ▓██▄   ▓██  ▒██░░██   █▌▒███   ▓██ ░▄█ ▒
 *   ▒   ██▒▓▓█  ░██░░▓█▄   ▌▒▓█  ▄ ▒██▀▀█▄
 * ▒██████▒▒▒▒█████▓ ░▒████▓ ░▒████▒░██▓ ▒██▒
 * ▒ ▒▓▒ ▒ ░░▒▓▒ ▒ ▒  ▒▒▓  ▒ ░░ ▒░ ░░ ▒▓ ░▒▓░
 * ░ ░▒  ░ ░░░▒░ ░ ░  ░ ▒  ▒  ░ ░  ░  ░▒ ░ ▒░
 * ░  ░  ░   ░░░ ░ ░  ░ ░  ░    ░     ░░   ░
 *       ░     ░        ░       ░  ░   ░
 *                    ░
 * </pre>
 *
 * @author topsuder
 * @date 2024/9/20-16:01
 * @see IntelliJ IDEA chatbots-yiwise-parent
 * @see ChatBotsClient 外呼client
 * @since <p>Copyright: 北京数字医信科技责任有限公司 (c) 2024</p>
 * <p>Company: 15303997779</p>
 */
public class ChatBotsClient {

    private final ChatbotsProperties chatbotsProperties;

    public ChatBotsClient(ChatbotsProperties chatbotsProperties) {
        this.chatbotsProperties = chatbotsProperties;
    }

    @SneakyThrows
    public HttpRequest build(Method method, String uri) {
        final HttpRequest request = HttpUtil.createRequest(method, URLUtil.completeUrl(chatbotsProperties.getBaseUrl(), chatbotsProperties.getVersion() + uri));
        request.header("appkey", chatbotsProperties.getAppKey());
        final Long timestamp = DateUtil.date().toTimestamp().getTime();
        request.header("signature", SignUtil.sign(chatbotsProperties.getAppKey()
                , chatbotsProperties.getAppSecret()
                , chatbotsProperties.getTenantSign()
                , chatbotsProperties.getVersion()
                , String.valueOf(timestamp)));
        request.header("timestamp", String.valueOf(timestamp));
        request.header("tenantsign", chatbotsProperties.getTenantSign());
        return request;
    }


}
