package com.cn.bjca.chatbots.core.pojo.job;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.time.LocalDate;
import java.util.List;
import java.util.Map;
import java.util.Set;

@Data
@NoArgsConstructor
@AllArgsConstructor
@Builder
public class ImportCustomerDTO {

    /**
     * 任务Id
     */
    private Long robotCallJobId;

    /**
     * 是否已呼列表去重 默认false
     */
    private Boolean callRecordDup = false;

    /**
     * 导入客户信息列表
     */
    private List<CustomerPersonDTO> customerPersons;

    /**
     * 所选地区是否为需要导入的地区
     * true: 所选地区导入； false: 所选地区不导入（默认状态）
     */
    private Boolean importSelected = false;

    /**
     * 省级归属地限制字段，省与省之间用‘,’分隔
     */
    private String provinceStr;

    /**
     * 市级归属地限制字段，市与市之间用’,’分隔
     */
    private String cityStr;

    /**
     * 是否计划内去重，仅针对当前任务属于外呼计划时生效
     */
    private Boolean distinctInPlan = false;

    /**
     * 性别枚举
     */
    public enum Gender {
        MALE, FEMALE
    }

    @Data
    @NoArgsConstructor
    @Builder
    @AllArgsConstructor
    public static class CustomerPersonDTO {

        /**
         * 客户电话，若为加密场景则传加密id
         * 长度不超过32个字符，若为虚拟号场景则传：手机号-分机号
         */
        private String phoneNumber;

        /**
         * 自定义变量，(可以在此处加上调用方的业务信息，在回调时会完整回传)
         */
        private Map<String, String> properties;

        /**
         * 客户自定义属性字段。
         * 自定义属性需要根据各企业在会员中心客户属性管理模块的设置进行赋值,
         * 如果自定义属性有字段设置为必填,那么客户必须携带该自定义属性,否则会失败
         */
        private Map<String, List<String>> customerAttr;

        /**
         * 客户名称
         */
        private String name;

        /**
         * 性别, MALE:男, FEMALE:女, 空值传null不要传空字符串
         */
        private Gender gender;

        /**
         * 副手机号
         */
        private List<String> alternatePhoneNumbers;

        /**
         * 标签id集合
         */
        private Set<Long> customerLevelTagDetailIds;

        /**
         * 客户生日
         */
        private LocalDate birthday;

        /**
         * 客户来源
         * TAO_BAO：淘宝, JD：京东, MINI_PROGRAM：小程序, WECHAT：企微, DOU_YIN：抖音,
         * KUAI_SHOU：快手, YOU_ZAN：有赞, OFF_LINE：线下门店, OTHER：其他
         */
        private List<String> createSources;

        /**
         * 微信昵称。加微推送中，选择指定账号模式下，给每个导入的客户添加指定加微账号，
         * 若指定账号不存在或者不可用时，该客户会进入到过滤列表
         */
        private String addWechatAccountName;
    }
}
