package com.cn.bjca.chatbots.core.pojo.job;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.Date;
import java.util.List;

@Data
@NoArgsConstructor
@Builder
@AllArgsConstructor
public class JobCreateDTO {

    // 任务名称（单个账户下任务名称需要保持唯一性）
    private String name;

    // 话术id，可以通过界面查询或者话术接口获取
    private Long dialogFlowId;

    // 任务启动方式 (MANUAL为手动启动, AUTO为自动启动)
    private String mode;

    // 任务自动启动日期，仅在mode为AUTO时必填
    private Date startTime;

    // 可拨打开始时间，默认不早于9点
    private String dailyStartTime;

    // 可拨打结束时间，默认不晚于20点
    private String dailyEndTime;

    // 任务使用的线路类型 (LANDLINE, MOBILE, CALL_POLICY_GROUP)
    private String phoneType;

    // 任务使用的AI并发数
    private Integer robotCount;

    // 线路id列表，当phoneType为LANDLINE时必填
    private List<Long> jobPhoneNumberIdList;

    // 线路并发数，默认与robotCount相同
    private Integer concurrencyQuota;

    // 外呼结束时间，外呼在设定时间后停止
    private Date endTime;

    // 不可拨打时间段，最多设置三个
    private List<InactiveTime> inactiveTimeList;

    // 不可拨打日期段，最多设置三个
    private List<InactiveDate> inactiveDateList;

    // 周可拨打时段，时段外任务挂起
    private List<String> daysOfWeek;

    // 是否只推送接通的客户
    private Boolean smsPushAnswered;

    // 短信发送类型 (DISTINCT_PUSH, EVERY_PUSH)
    private String smsPushType;

    // 短信模板id
    private Long smsTemplateId;

    // 推送短信的意向等级ID
    private List<Integer> smsAlertLevelCode;

    // 自动重播条件设置
    private List<RedialSetting> redialSettingList;

    // 微信推送条件设置
    private List<WechatPushCondition> wechatPushConditionList;

    // 人工介入坐席组id
    private Long csStaffGroupId;

    // 是否设定为优先任务
    private Boolean isPrior;

    // 是否开启弹性坐席功能
    private Boolean enableElasticRobot;

    // 预警消息推送用户id列表
    private List<Long> earlyWarningAlertUsers;

    // 任务备注
    private String description;

    // 黑名单分组ID
    private List<Long> customerWhiteGroupIds;

    // 风控策略ID
    private Long riskControlStrategyId;

    // 闪信模板ID
    private Long flashMessageTemplateId;

    // 补发短信模板id列表
    private List<Long> reSendSmsTemplateIds;

    // 短信补发开关
    private Boolean enableReSendSms;

    // 话术短信模板ID
    private Long botSmsTemplateId;

    // 嵌套类 - 不可拨打时间段
    @Data
    @NoArgsConstructor
    @Builder
    @AllArgsConstructor
    public static class InactiveTime {
        private String startTime;
        private String endTime;
    }

    // 嵌套类 - 不可拨打日期段
    @Data
    @NoArgsConstructor
    public static class InactiveDate {
        private Date startDate;
        private Date endDate;
    }

    // 嵌套类 - 自动重播条件
    @Data
    @NoArgsConstructor
    @Builder
    @AllArgsConstructor
    public static class RedialSetting {
        private List<String> redialCondition;
        private Integer redialInterval;
        private Integer redialTimes;
        private String redialType;
        private List<Integer> connectRedialCondition;
    }

    // 嵌套类 - 微信推送条件
    @Data
    @NoArgsConstructor
    @Builder
    @AllArgsConstructor
    public static class WechatPushCondition {
        private List<Integer> intentLevelCodes;
        private Integer durationThreshold;
        private List<Long> userIds;
        private String wechatSendMethod;
        private Boolean transferCustomer;
    }
}