package com.cn.bjca.chatbots.core.service;

import com.cn.bjca.chatbots.core.pojo.ApiResponse;
import com.cn.bjca.chatbots.core.pojo.PageResult;
import com.cn.bjca.chatbots.core.pojo.dialogflow.DialogFlow;
import com.cn.bjca.chatbots.core.pojo.dialogflow.DialogFlowPageDTO;

import java.util.List;

/**
 * <pre>基础信息接口</pre>
 *
 * <p>Description</p>
 * <pre>
 *     __
 *    / /____  ___
 *   / __/ _ \/ _ \
 *   \__/\___/ .__/
 *          / / Coding is an art,
 *         /_/      And I'm its Picasso.
 *
 *   ██████  █    ██ ▓█████▄ ▓█████  ██▀███
 * ▒██    ▒  ██  ▓██▒▒██▀ ██▌▓█   ▀ ▓██ ▒ ██▒
 * ░ ▓██▄   ▓██  ▒██░░██   █▌▒███   ▓██ ░▄█ ▒
 *   ▒   ██▒▓▓█  ░██░░▓█▄   ▌▒▓█  ▄ ▒██▀▀█▄
 * ▒██████▒▒▒▒█████▓ ░▒████▓ ░▒████▒░██▓ ▒██▒
 * ▒ ▒▓▒ ▒ ░░▒▓▒ ▒ ▒  ▒▒▓  ▒ ░░ ▒░ ░░ ▒▓ ░▒▓░
 * ░ ░▒  ░ ░░░▒░ ░ ░  ░ ▒  ▒  ░ ░  ░  ░▒ ░ ▒░
 * ░  ░  ░   ░░░ ░ ░  ░ ░  ░    ░     ░░   ░
 *       ░     ░        ░       ░  ░   ░
 *                    ░
 * </pre>
 *
 * @author topsuder
 * @date 2024/9/20-15:58
 * @see IntelliJ IDEA chatbots-yiwise-parent
 * @see DialogFlowService 基础信息接口
 * @since <p>Copyright: 北京数字医信科技责任有限公司 (c) 2024</p>
 * <p>Company: 15303997779</p>
 */
public interface DialogFlowService {


    /**
     * 方法注释: <br>
     * 〈话术列表〉
     *
     * @return com.cn.bjca.chatbots.core.pojo.ApiResponse<com.cn.bjca.chatbots.core.pojo.PageResult < com.cn.bjca.chatbots.core.pojo.dialogflow.DialogFlow>>
     * @apiNote 功能说明： 通过接口可以获取所有话术列表
     * 请求地址： https://openapi.tanyibot.com/apiOpen/v1/dialogFlow/getTotalDialogFlowList
     * 请求方法： POST
     * @param    dialogFlowPageDTO
     * @author topsuder 🪖🇨🇳
     * @date 2024/9/24 14:08
     */ 
    ApiResponse<PageResult<DialogFlow>> getTotalDialogFlowList(DialogFlowPageDTO dialogFlowPageDTO);


    /**
     * 方法注释: <br>
     * 〈已发布的列表查询接口〉
     *
     * @apiNote
     * 功能说明： 通过接口可以获取指定公司的所有配置完成的机器人话术，注意：该接口仅能查询发布过的话术，如果想获取全部话术，参考：话术列表
     * 请求地址： <a href="https://openapi.tanyibot.com/apiOpen/v1/dialogFlow/getDialogFlowList">...</a>
     * 请求方法： GET
     * @param    dialogFlowPageDTO 数据传输对象
     * @return com.cn.bjca.chatbots.core.pojo.ApiResponse<com.cn.bjca.chatbots.core.pojo.PageResult < com.cn.bjca.chatbots.core.pojo.dialogflow.DialogFlow>>
     * @author topsuder 🪖🇨🇳
     * @date 2024/9/24 14:07
     */
    ApiResponse<List<DialogFlow>> getDialogFlowList();
}
