package com.cn.bjca.chatbots.core.service;

import com.cn.bjca.chatbots.core.pojo.ApiResponse;
import com.cn.bjca.chatbots.core.pojo.job.ImportCustomerDTO;
import com.cn.bjca.chatbots.core.pojo.job.ImportCustomerRep;
import com.cn.bjca.chatbots.core.pojo.job.JobCreateDTO;

/**
 * <pre>外呼任务接口</pre>
 *
 * <p>Description</p>
 * <pre>
 *     __
 *    / /____  ___
 *   / __/ _ \/ _ \
 *   \__/\___/ .__/
 *          / / Coding is an art,
 *         /_/      And I'm its Picasso.
 *
 *   ██████  █    ██ ▓█████▄ ▓█████  ██▀███
 * ▒██    ▒  ██  ▓██▒▒██▀ ██▌▓█   ▀ ▓██ ▒ ██▒
 * ░ ▓██▄   ▓██  ▒██░░██   █▌▒███   ▓██ ░▄█ ▒
 *   ▒   ██▒▓▓█  ░██░░▓█▄   ▌▒▓█  ▄ ▒██▀▀█▄
 * ▒██████▒▒▒▒█████▓ ░▒████▓ ░▒████▒░██▓ ▒██▒
 * ▒ ▒▓▒ ▒ ░░▒▓▒ ▒ ▒  ▒▒▓  ▒ ░░ ▒░ ░░ ▒▓ ░▒▓░
 * ░ ░▒  ░ ░░░▒░ ░ ░  ░ ▒  ▒  ░ ░  ░  ░▒ ░ ▒░
 * ░  ░  ░   ░░░ ░ ░  ░ ░  ░    ░     ░░   ░
 *       ░     ░        ░       ░  ░   ░
 *                    ░
 * </pre>
 *
 * @author topsuder
 * @date 2024/9/23-17:18
 * @see IntelliJ IDEA chatbots-yiwise-parent
 * @see JobService 外呼任务接口
 * @since <p>Copyright: 北京数字医信科技责任有限公司 (c) 2024</p>
 * <p>Company: 15303997779</p>
 */
public interface JobService {


    /**
     * 方法注释: <br>
     * 〈新增任务接口〉
     *
     * @param jobCreateDTO 请求对象
     * @return com.cn.bjca.chatbots.core.pojo.ApiResponse<java.lang.Long>
     * @apiNote 功能说明： 通过此接口在AICC新增任务 ,AI外呼是围绕着任务进行的，用户将话术（AI的对话逻辑），线路（AI外呼的外显号码），并发（AI外呼同时进行的个数）外呼时段等必要属性通过新建任务的动作赋予任务后可以通过开启，暂停，修改任务等方式控制AI外呼的过程。
     * 请求地址： <a href="https://openapi.tanyibot.com/apiOpen/v1/job/create">...</a>
     * 请求方法： POST
     * @author topsuder 🪖🇨🇳
     * @date 2024/9/24 11:23
     */
    ApiResponse<Long> create(JobCreateDTO jobCreateDTO);

    /**
     * 方法注释: <br>
     * 〈向任务中导入客户接口〉
     *
     * @param importCustomerDTO 请求对象
     * @return com.cn.bjca.chatbots.core.pojo.ApiResponse<java.lang.Long>
     * @apiNote 功能说明：
     * 通过此接口可以向指定的任务导入客户信息，用于拨打电话。（单次导入客户数量不能大于100）
     * 此接口是公网服务，所有客户共用，为保证接口响应速度和吞吐量，并控制服务器压力，将单次导入个数定位100个。数据量大时可以多并发调用此接口来实现。
     * 导入的客户，如果部分成功部分失败的话，会返回200，同时会把导入失败的客户在data中返回。
     * 如果被导入账户支持虚拟号外呼（需要业务侧沟通），可以按照：11位手机号+1-4位分机号的模式导入号码。
     * 请求地址： <a href="https://openapi.tanyibot.com/apiOpen/v1/job/importCustomer">...</a>
     * 请求方法： POST
     * @author topsuder 🪖🇨🇳
     * @date 2024/9/24 11:23
     */
    ApiResponse<ImportCustomerRep> importCustomer(ImportCustomerDTO importCustomerDTO);
}
