package com.cn.bjca.chatbots.core.service.impl;

import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import cn.hutool.http.Method;
import com.cn.bjca.chatbots.core.client.ChatBotsClient;
import com.cn.bjca.chatbots.core.pojo.ApiResponse;
import com.cn.bjca.chatbots.core.pojo.PageResult;
import com.cn.bjca.chatbots.core.pojo.dialogflow.DialogFlow;
import com.cn.bjca.chatbots.core.pojo.dialogflow.DialogFlowPageDTO;
import com.cn.bjca.chatbots.core.pool.UrlPool;
import com.cn.bjca.chatbots.core.service.DialogFlowService;
import com.cn.bjca.chatbots.core.util.GsonUtil;
import com.google.gson.reflect.TypeToken;
import lombok.Cleanup;
import lombok.extern.slf4j.Slf4j;

import javax.annotation.Resource;
import java.lang.reflect.Type;
import java.util.List;

/**
 * <pre></pre>
 *
 * <p>Description</p>
 * <pre>
 *     __
 *    / /____  ___
 *   / __/ _ \/ _ \
 *   \__/\___/ .__/
 *          / / Coding is an art,
 *         /_/      And I'm its Picasso.
 *
 *   ██████  █    ██ ▓█████▄ ▓█████  ██▀███
 * ▒██    ▒  ██  ▓██▒▒██▀ ██▌▓█   ▀ ▓██ ▒ ██▒
 * ░ ▓██▄   ▓██  ▒██░░██   █▌▒███   ▓██ ░▄█ ▒
 *   ▒   ██▒▓▓█  ░██░░▓█▄   ▌▒▓█  ▄ ▒██▀▀█▄
 * ▒██████▒▒▒▒█████▓ ░▒████▓ ░▒████▒░██▓ ▒██▒
 * ▒ ▒▓▒ ▒ ░░▒▓▒ ▒ ▒  ▒▒▓  ▒ ░░ ▒░ ░░ ▒▓ ░▒▓░
 * ░ ░▒  ░ ░░░▒░ ░ ░  ░ ▒  ▒  ░ ░  ░  ░▒ ░ ▒░
 * ░  ░  ░   ░░░ ░ ░  ░ ░  ░    ░     ░░   ░
 *       ░     ░        ░       ░  ░   ░
 *                    ░
 * </pre>
 *
 * @author topsuder
 * @date 2024/9/20-15:59
 * @see IntelliJ IDEA chatbots-yiwise-parent
 * @see DialogFlowServiceImpl
 * @since <p>Copyright: 北京数字医信科技责任有限公司 (c) 2024</p>
 * <p>Company: 15303997779</p>
 */
@Slf4j
public class DialogFlowServiceImpl implements DialogFlowService {

    @Resource
    private ChatBotsClient chatBotsClient;

    @Override
    public ApiResponse<PageResult<DialogFlow>> getTotalDialogFlowList(DialogFlowPageDTO dialogFlowPageDTO) {
        final HttpRequest request
                = chatBotsClient.build(Method.POST, UrlPool.DialogFlowPool.GET_TOTAL_DIALOGFLOW_LIST);
        request.body(GsonUtil.X.getGson().toJson(dialogFlowPageDTO));
        @Cleanup final HttpResponse execute = request.execute();
        final String body = execute.body();
        Type type = new TypeToken<ApiResponse<PageResult<DialogFlow>>>() {
        }.getType();
        return GsonUtil.X.getGson().fromJson(body, type);
    }

    @Override
    public ApiResponse<List<DialogFlow>> getDialogFlowList() {
        final HttpRequest request
                = chatBotsClient.build(Method.GET, UrlPool.DialogFlowPool.GET_DIALOGFLOW_LIST);
        @Cleanup final HttpResponse execute = request.execute();
        final String body = execute.body();
        System.out.println(body);
        Type type = new TypeToken<ApiResponse<List<DialogFlow>>>() {
        }.getType();
        return GsonUtil.X.getGson().fromJson(body, type);
    }


}
