package com.cn.bjca.chatbots.core.service.impl;

import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import cn.hutool.http.Method;
import com.cn.bjca.chatbots.core.client.ChatBotsClient;
import com.cn.bjca.chatbots.core.pojo.ApiResponse;
import com.cn.bjca.chatbots.core.pojo.job.ImportCustomerDTO;
import com.cn.bjca.chatbots.core.pojo.job.ImportCustomerRep;
import com.cn.bjca.chatbots.core.pojo.job.JobCreateDTO;
import com.cn.bjca.chatbots.core.pool.UrlPool;
import com.cn.bjca.chatbots.core.service.JobService;
import com.cn.bjca.chatbots.core.util.GsonUtil;
import com.google.gson.reflect.TypeToken;
import lombok.Cleanup;

import javax.annotation.Resource;
import java.lang.reflect.Type;

/**
 * <pre>外呼任务接口实现</pre>
 *
 * <p>Description</p>
 * <pre>
 *     __
 *    / /____  ___
 *   / __/ _ \/ _ \
 *   \__/\___/ .__/
 *          / / Coding is an art,
 *         /_/      And I'm its Picasso.
 *
 *   ██████  █    ██ ▓█████▄ ▓█████  ██▀███
 * ▒██    ▒  ██  ▓██▒▒██▀ ██▌▓█   ▀ ▓██ ▒ ██▒
 * ░ ▓██▄   ▓██  ▒██░░██   █▌▒███   ▓██ ░▄█ ▒
 *   ▒   ██▒▓▓█  ░██░░▓█▄   ▌▒▓█  ▄ ▒██▀▀█▄
 * ▒██████▒▒▒▒█████▓ ░▒████▓ ░▒████▒░██▓ ▒██▒
 * ▒ ▒▓▒ ▒ ░░▒▓▒ ▒ ▒  ▒▒▓  ▒ ░░ ▒░ ░░ ▒▓ ░▒▓░
 * ░ ░▒  ░ ░░░▒░ ░ ░  ░ ▒  ▒  ░ ░  ░  ░▒ ░ ▒░
 * ░  ░  ░   ░░░ ░ ░  ░ ░  ░    ░     ░░   ░
 *       ░     ░        ░       ░  ░   ░
 *                    ░
 * </pre>
 *
 * @author topsuder
 * @date 2024/9/23-17:19
 * @see IntelliJ IDEA chatbots-yiwise-parent
 * @see JobServiceImpl
 * @since <p>Copyright: 北京数字医信科技责任有限公司 (c) 2024</p>
 * <p>Company: 15303997779</p>
 */
public class JobServiceImpl implements JobService {

    @Resource
    private ChatBotsClient chatBotsClient;

    @Override
    public ApiResponse<Long> create(JobCreateDTO jobCreateDTO) {
        final HttpRequest request
                = chatBotsClient.build(Method.POST, UrlPool.JobPool.CREATE);
        request.body(GsonUtil.X.getGson().toJson(jobCreateDTO));
        @Cleanup final HttpResponse execute = request.execute();
        final String body = execute.body();
        Type type = new TypeToken<ApiResponse<Long>>() {
        }.getType();
        return GsonUtil.X.getGson().fromJson(body, type);
    }

    @Override
    public ApiResponse<ImportCustomerRep> importCustomer(ImportCustomerDTO importCustomerDTO) {
        final HttpRequest request
                = chatBotsClient.build(Method.POST, UrlPool.JobPool.IMPORT_CUSTOMER);
        request.body(GsonUtil.X.getGson().toJson(importCustomerDTO));
        @Cleanup final HttpResponse execute = request.execute();
        final String body = execute.body();
        Type type = new TypeToken<ApiResponse<ImportCustomerRep>>() {
        }.getType();
        return GsonUtil.X.getGson().fromJson(body, type);
    }


}
