package com.szyx.spring.boot.autoconfigure;

import com.cn.bjca.chatbots.core.callback.controller.CallRecordCallbackController;
import com.cn.bjca.chatbots.core.client.ChatBotsClient;
import com.cn.bjca.chatbots.core.properties.ChatbotsProperties;
import com.cn.bjca.chatbots.core.service.DialogFlowService;
import com.cn.bjca.chatbots.core.service.JobService;
import com.cn.bjca.chatbots.core.service.impl.DialogFlowServiceImpl;
import com.cn.bjca.chatbots.core.service.impl.JobServiceImpl;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * <pre>即时通讯自动配置类</pre>
 *
 * <span>Form File</span>
 * <p>Description</p>
 * <p>Copyright: 北京数字医信科技责任有限公司 (c) 2023</p>
 * <p>Company:Wechat 15303997779</p>
 *
 * @author topsuder
 * @version v1.0.0
 * @DATE 2023/12/11-13:53
 * @Description
 * @see com.szyx.spring.boot.autoconfigure chat-parent
 */
@Configuration(proxyBeanMethods = false)
@EnableConfigurationProperties(ChatbotsProperties.class)
public class ChatBotsAutoConfiguration {


    private final ChatbotsProperties chatbotsProperties;

    public ChatBotsAutoConfiguration(ChatbotsProperties chatbotsProperties) {
        this.chatbotsProperties = chatbotsProperties;
    }

    /**
     * 自动配置 CallRecordCallbackController。
     * 如果业务系统没有定义 CallRecordCallbackController，则使用该默认实现。
     */
    @Bean
    @ConditionalOnMissingBean
    public CallRecordCallbackController callRecordCallbackController() {
        return new CallRecordCallbackController();
    }


    @Bean
    @ConditionalOnMissingBean
    public ChatBotsClient defaultChatBotsClient() {
        return new ChatBotsClient(chatbotsProperties);
    }


    @Bean("dialogFlowServiceImpl")
    @SuppressWarnings("all")
    @ConditionalOnMissingBean
    public DialogFlowService dialogFlowService() {
        return new DialogFlowServiceImpl();
    }

    @Bean
    @SuppressWarnings("all")
    @ConditionalOnMissingBean
    public JobService jobService() {
        return new JobServiceImpl();
    }

}
